@@ -1,11 +1,12 @@
 from yledl import download, StreamAction
-from downloaders import StreamFilters, IOContext, BackendFactory, \
-    RD_SUCCESS, RD_FAILED, RD_INCOMPLETE
+from downloaders import StreamFilters, IOContext, DownloadLimits, \
+    BackendFactory, RD_SUCCESS, RD_FAILED, RD_INCOMPLETE
 from version import version
 
 __all__ = [
     'download',
     'StreamFilters',
+    'DownloadLimits',
     'IOContext',
     'BackendFactory',
     'StreamAction',
